@@ -402,6 +402,39 @@ def test_add_chip_mapped_read_length(
         assert result == {"mapped_read_length": expected_value}
 
 
+@pytest.mark.parametrize(
+    "qc,condition,expected",
+    [
+        (
+            {"general": {"seq_endedness": {"rep1": {"paired_end": True}}}},
+            does_not_raise(),
+            {"mapped_run_type": "paired-ended"},
+        ),
+        (
+            {"general": {"seq_endedness": {"rep1": {"paired_end": False}}}},
+            does_not_raise(),
+            {"mapped_run_type": "single-ended"},
+        ),
+        (
+            {"general": {"seq_endedness": {"rep1": {"paired_end": "true"}}}},
+            pytest.raises(TypeError),
+            {},
+        ),
+    ],
+)
+def test_accession_chip_add_mapped_run_type(
+    mocker, mock_accession_chip, gsfile, qc, condition, expected
+):
+    mocker.patch.object(mock_accession_chip.analysis, "get_files")
+    mocker.patch.object(mock_accession_chip.backend, "read_json", return_value=qc)
+    mocker.patch.object(
+        mock_accession_chip, "get_chip_pipeline_replicate", return_value="rep1"
+    )
+    with condition:
+        result = mock_accession_chip.add_mapped_run_type(gsfile)
+        assert result == expected
+
+
 @pytest.mark.parametrize(
     "gsfile_task,expected",
     [
@@ -422,6 +455,35 @@ def test_maybe_add_chip_cropped_read_length(
     assert result == expected
 
 
+@pytest.mark.parametrize(
+    "gsfile_task,expected",
+    [
+        (
+            Task(
+                "my_task",
+                {"inputs": {"crop_length": 0, "crop_length_tol": 2}, "outputs": {}},
+            ),
+            {},
+        ),
+        (
+            Task(
+                "my_task",
+                {"inputs": {"crop_length": 10, "crop_length_tol": 2}, "outputs": {}},
+            ),
+            {"cropped_read_length_tolerance": 2},
+        ),
+    ],
+)
+def test_maybe_add_chip_cropped_read_length_tolerance(
+    mocker, mock_accession_chip, gsfile, gsfile_task, expected
+):
+    mocker.patch.object(
+        mock_accession_chip.analysis, "get_tasks", return_value=[gsfile_task]
+    )
+    result = mock_accession_chip.maybe_add_cropped_read_length_tolerance(gsfile)
+    assert result == expected
+
+
 @pytest.mark.parametrize(
     "processing_stage,align_qc",
     [("unfiltered", align_qc_dup), ("filtered", align_qc_nodup)],
